@@ -33,13 +33,7 @@ impl<'a> Lookahead<'a> {
     pub fn field(&self, name: &str) -> Self {
         let mut fields = Vec::new();
         for field in &self.fields {
-            filter(
-                &mut fields,
-                self.fragments,
-                &field.selection_set.node,
-                name,
-                self.context,
-            )
+            filter(&mut fields, self.fragments, &field.selection_set.node, name)
         }
 
         Self {
@@ -108,7 +102,6 @@ fn filter<'a>(
     fragments: &'a HashMap<Name, Positioned<FragmentDefinition>>,
     selection_set: &'a SelectionSet,
     name: &str,
-    context: &'a Context<'a>,
 ) {
     for item in &selection_set.items {
         match &item.node {
@@ -117,22 +110,12 @@ fn filter<'a>(
                     fields.push(&field.node)
                 }
             }
-            Selection::InlineFragment(fragment) => filter(
-                fields,
-                fragments,
-                &fragment.node.selection_set.node,
-                name,
-                context,
-            ),
+            Selection::InlineFragment(fragment) => {
+                filter(fields, fragments, &fragment.node.selection_set.node, name)
+            }
             Selection::FragmentSpread(spread) => {
                 if let Some(fragment) = fragments.get(&spread.node.fragment_name.node) {
-                    filter(
-                        fields,
-                        fragments,
-                        &fragment.node.selection_set.node,
-                        name,
-                        context,
-                    )
+                    filter(fields, fragments, &fragment.node.selection_set.node, name)
                 }
             }
         }
