@@ -6,6 +6,7 @@ use indexmap::map::IndexMap;
 use crate::connection::edge::Edge;
 use crate::connection::page_info::PageInfo;
 use crate::parser::types::Field;
+use crate::registry::MetaTypeId;
 use crate::resolver_utils::{resolve_container, ContainerType};
 use crate::types::connection::{CursorType, EmptyFields};
 use crate::{
@@ -163,7 +164,7 @@ where
     }
 
     fn create_type_info(registry: &mut registry::Registry) -> String {
-        registry.create_output_type::<Self, _>(|registry| {
+        registry.create_output_type::<Self, _>(MetaTypeId::Object,|registry| {
             EC::create_type_info(registry);
             let additional_fields = if let Some(registry::MetaType::Object { fields, .. }) =
             registry.types.remove(EC::type_name().as_ref())
